..
    Copyright (C) 2022 CERN.

    Invenio-Users-Resources is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.

Changes
=======

Version 1.1.0 (released 2023-03-02)

- remove deprecated flask-babelex dependency and imports

Version 1.0.2 (released 2022-12-01)

- Add identity to links template expand method

Version 1.0.1 (released 2022-11-15)

- use bulk indexing for `rebuild_index` method in users/groups

Version 1.0.0

- Initial public release.
